**Example 1: 删除定时任务**

删除定时任务

Input: 

```
tccli pts DeleteCronJobs --cli-unfold-argument  \
    --ProjectId xx \
    --CronJobIds xx
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

